<?php

class actionContentItemRandom extends cmsAction {

    public function run(){

        if (!$this->request->isAjax()){ cmsCore::error404(); }

        $template = cmsTemplate::getInstance();

        $widget_id = $this->request->get('widget_id');
        $item_old_id = $this->request->get('item_id');
        $ctype_name = $this->request->get('ctype_name');
        $amount_items = $this->request->get('amount_items');
        $image_field = $this->request->get('image_field');
        $teaser_field = $this->request->get('teaser_field');
        $teaser_max_length = $this->request->get('teaser_max_length');
        $is_comments = $this->request->get('is_comments');
       
        
        // Отключаем фильтр приватности для тех кому это разрешено
        if (cmsUser::isAllowed($ctype_name, 'view_all')) {
            $this->model->disablePrivacyFilter();
        }

        // Скрываем записи из скрытых родителей (приватных групп и т.п.)
        $this->model->filterHiddenParents();    

        $all_items = $this->model->getContentItems($ctype_name);
        
        if (!$all_items){
            $result = array('error' => false, 'total' => 0);
            $template->renderJSON($result);
            return false;
        }
        
        do {    // чтобы 2 раза не выводился одинаковый контент 
            shuffle($all_items);
        } while ($all_items[0]['id']==$item_old_id);
        
        $items = array_slice($all_items, 0, (int)$amount_items);  
        
        foreach ($items as &$item) {

            $date = new DateTime($item['date_pub']);  

            $teaser_text = html_clean($item[$teaser_field]);
            if ($teaser_max_length>0 && strlen($teaser_text)>$teaser_max_length) {
                $teaser_text = substr($teaser_text,0,strripos(substr($teaser_text,0,(int)$teaser_max_length),' ')).' ...';
            }
            
            $item['teaser_text'] = $teaser_text;
            $item['url'] = href_to($ctype_name, $item['slug']) . '.html'; //ссылка на контент
            $item['image'] = html_image($item[$image_field], big); // ссылка на картинку (возвращает тег img)
            $item['title'] = htmlspecialchars($item['title']);
            $item['url_author'] = href_to('users', $item['user']['id']);
            $item['author'] = htmlspecialchars($item['user']['nickname']);
            $item['date'] = htmlspecialchars($date->format('d.m.Y'));            
        }
        
        shuffle($items);

        // Формируем и возвращаем результат
        $result = array(
            'error' => false,
            'widget_id' => $widget_id, 
            'items' => $items,
            'comments' => $is_comments ? intval($item['comments']) : false                
        );

        $template->renderJSON($result);

    }

}
